@@ -5,7 +5,9 @@
 #include <QAbstractListModel>
 #include <QSharedPointer>
 
+#ifndef QML_USER_INTERFACE
 class ThumbnailCache;
+#endif
 
 class AbstractGroupListModel : public QAbstractListModel
 {
@@ -18,36 +20,42 @@ public:
         ArtistRole,
         DateRole,
         VideoCountRole,
+#ifndef QML_USER_INTERFACE
         ThumbnailRole,
+#endif
         ThumbnailUrlRole,
         DescriptionRole
     };
 
 public:
-    explicit AbstractGroupListModel(ThumbnailCache *cache = 0, QObject *parent = 0);
+    explicit AbstractGroupListModel(QObject *parent = 0);
     ~AbstractGroupListModel();
-    inline ThumbnailCache* thumbnailCache() const { return m_cache; }
-    void setThumbnailCache(ThumbnailCache *cache);
     int rowCount(const QModelIndex &parent = QModelIndex()) const;
     QVariant data(const QModelIndex &index, int role) const;
     Q_INVOKABLE QVariant data(int row, const QByteArray &role) const;
     QSharedPointer<GroupItem> get(int row) const;
+#ifdef QML_USER_INTERFACE
     Q_INVOKABLE GroupItem* getFromQML(int row) const;
+#endif
+
+public slots:
+    void clear();
     void insertGroup(int row, QSharedPointer<GroupItem> group);
     void appendGroup(QSharedPointer<GroupItem> group);
     bool removeGroup(const QVariant &value, int role = IdRole);
 
-public slots:
-    void clear();
-
 protected:
     bool removeRow(int row, const QModelIndex &parent = QModelIndex());
 
+#ifndef QML_USER_INTERFACE
 protected slots:
     void onThumbnailReady();
+#endif
 
 protected:
+#ifndef QML_USER_INTERFACE
     ThumbnailCache *m_cache;
+#endif
     QList< QSharedPointer<GroupItem> > m_list;
 };
 
