@@ -14,12 +14,14 @@ AbstractPlaylistListModel::AbstractPlaylistListModel(QObject *parent) :
     roles[PlaylistIdRole] = "playlistId";
     roles[TitleRole] = "title";
     roles[ArtistRole] = "artist";
+    roles[ArtistAvatarUrlRole] = "artistAvatarUrl";
     roles[DateRole] = "date";
     roles[VideoCountRole] = "videoCount";
 #ifndef QML_USER_INTERFACE
     roles[ThumbnailRole] = "thumbnail";
 #endif
     roles[ThumbnailUrlRole] = "thumbnailUrl";
+    roles[LargeThumbnailUrlRole] = "largeThumbnailUrl";
     roles[DescriptionRole] = "description";
     this->setRoleNames(roles);
 #ifndef QML_USER_INTERFACE
@@ -57,6 +59,8 @@ QVariant AbstractPlaylistListModel::data(const QModelIndex &index, int role) con
         return m_list.at(index.row()).data()->title();
     case ArtistRole:
         return m_list.at(index.row()).data()->artist();
+    case ArtistAvatarUrlRole:
+        return m_list.at(index.row()).data()->artistAvatarUrl();
     case DateRole:
         return m_list.at(index.row()).data()->date();
     case VideoCountRole:
@@ -67,6 +71,8 @@ QVariant AbstractPlaylistListModel::data(const QModelIndex &index, int role) con
 #endif
     case ThumbnailUrlRole:
         return m_list.at(index.row()).data()->thumbnailUrl();
+    case LargeThumbnailUrlRole:
+        return m_list.at(index.row()).data()->largeThumbnailUrl();
     case DescriptionRole:
         return m_list.at(index.row()).data()->description();
     default:
