@@ -19,12 +19,14 @@ public:
         PlaylistIdRole,
         TitleRole,
         ArtistRole,
+        ArtistAvatarUrlRole,
         DateRole,
         VideoCountRole,
 #ifndef QML_USER_INTERFACE
         ThumbnailRole,
 #endif
         ThumbnailUrlRole,
+        LargeThumbnailUrlRole,
         DescriptionRole
     };
 
