@@ -17,6 +17,7 @@ AbstractVideoListModel::AbstractVideoListModel(QObject *parent) :
     roles[PlaylistVideoIdRole] = "playlistVideoId";
     roles[TitleRole] = "title";
     roles[ArtistRole] = "artist";
+    roles[ArtistAvatarUrlRole] = "artistAvatarUrl";
     roles[DateRole] = "date";
     roles[DurationRole] = "duration";
     roles[ViewCountRole] = "viewCount";
@@ -29,6 +30,7 @@ AbstractVideoListModel::AbstractVideoListModel(QObject *parent) :
     roles[ThumbnailPressedRole] = "thumbnailPressed";
 #endif
     roles[ThumbnailUrlRole] = "thumbnailUrl";
+    roles[LargeThumbnailUrlRole] = "largeThumbnailUrl";
     roles[ArchiveRole] = "archive";
     roles[ServiceRole] = "service";
     roles[FavouriteRole] = "favourite";
@@ -73,6 +75,8 @@ QVariant AbstractVideoListModel::data(const QModelIndex &index, int role) const
         return m_list.at(index.row()).data()->title();
     case ArtistRole:
         return m_list.at(index.row()).data()->artist();
+    case ArtistAvatarUrlRole:
+        return m_list.at(index.row()).data()->artistAvatarUrl();
     case DateRole:
         return m_list.at(index.row()).data()->date();
     case DurationRole:
@@ -95,6 +99,8 @@ QVariant AbstractVideoListModel::data(const QModelIndex &index, int role) const
 #endif
     case ThumbnailUrlRole:
         return m_list.at(index.row()).data()->thumbnailUrl();
+    case LargeThumbnailUrlRole:
+        return m_list.at(index.row()).data()->largeThumbnailUrl();
     case ServiceRole:
         return m_list.at(index.row()).data()->service();
     case FavouriteRole:
