@@ -21,6 +21,7 @@ public:
         PlaylistVideoIdRole,
         TitleRole,
         ArtistRole,
+        ArtistAvatarUrlRole,
         DateRole,
         DurationRole,
         ViewCountRole,
@@ -33,6 +34,7 @@ public:
         ThumbnailPressedRole,
 #endif
         ThumbnailUrlRole,
+        LargeThumbnailUrlRole,
         ArchiveRole,
         ServiceRole,
         FavouriteRole,
