@@ -317,7 +317,7 @@ void Dailymotion::clearCache() {
 }
 
 void Dailymotion::signOut() {
-    this->setBusy(true, tr("Signing out..."));
+    this->setBusy(true, tr("Signing out"));
     QUrl url("https://api.dailymotion.com/logout");
     QNetworkRequest request(url);
     request.setRawHeader("User-Agent", QString("cuteTube/%1 (Qt)").arg(Utils::versionNumberString()).toUtf8());
