@@ -1,7 +1,6 @@
 #include "database.h"
 #include "settings.h"
 #include "utils.h"
-#include <qplatformdefs.h>
 #include <QFileInfo>
 #include <QDir>
 #include <QSqlQuery>
@@ -450,7 +449,11 @@ bool Database::storeDownload(QSharedPointer<TransferItem> transfer) {
         query.addBindValue(transfer.data()->fileName());
         query.addBindValue(Services::VideoService(transfer.data()->service()));
         query.addBindValue(Videos::VideoFormat(transfer.data()->videoFormat()));
+#ifdef MEEGO_EDITION_HARMATTAN
+        query.addBindValue(Transfers::TransferPriority(Transfers::NormalPriority));
+#else
         query.addBindValue(Transfers::TransferPriority(transfer.data()->priority()));
+#endif
         query.addBindValue(transfer.data()->saveAsAudio());
         query.addBindValue(0);
         bool success = query.exec();
@@ -512,7 +515,9 @@ QList< QSharedPointer<TransferItem> > Database::getStoredDownloads() {
                 transfer.data()->setFileName(query.value(6).toString());
                 transfer.data()->setService(static_cast<Services::VideoService>(query.value(7).toInt()));
                 transfer.data()->setVideoFormat(static_cast<Videos::VideoFormat>(query.value(8).toInt()));
+#ifndef MEEGO_EDITION_HARMATTAN
                 transfer.data()->setPriority(static_cast<Transfers::TransferPriority>(query.value(9).toInt()));
+#endif
                 transfer.data()->setSaveAsAudio(query.value(10).toBool());
                 transfer.data()->setSize(query.value(11).toLongLong());
 
