@@ -40,8 +40,10 @@ void ScreenSaver::preventBlanking(bool prevent) {
         m_displayState.cancelBlankingPause();
         m_timer.stop();
     }
-#else
+#elif !defined (Q_WS_SIMULATOR)
     m_screenSaver.setScreenSaverInhibited(prevent);
+#else
+    Q_UNUSED(prevent)
 #endif
 }
 #endif
