@@ -10,6 +10,8 @@
 #include "../maemo5_gui/transferitem.h"
 #elif (defined (SYMBIAN_OS))
 #include "../symbian/transferitem.h"
+#elif (defined (Q_OS_UNIX))
+#include "../tv/transferitem.h"
 #endif
 
 
