@@ -270,6 +270,62 @@ QMap<int, QUrl> UrlGrabber::getYouTubeVideoUrlMap(QString page, QScriptValue dec
 
 void UrlGrabber::getYouTubeVideoUrl(const QString &id) {
     this->setBusy(true, tr("Loading video"));
+    this->getYouTubeVideoInfoPage(id, SLOT(checkYouTubeVideoInfoPage()));
+}
+
+void UrlGrabber::getYouTubeVideoInfoPage(const QString &id, const char *slot) {
+    QUrl url("http://www.youtube.com/get_video_info");
+    url.addQueryItem("video_id", id);
+    url.addQueryItem("el", "detailpage");
+    url.addQueryItem("ps", "default");
+    url.addQueryItem("eurl", "gl");
+    url.addQueryItem("gl", "US");
+    url.addQueryItem("hl", "en");
+    QNetworkRequest request(url);
+    request.setRawHeader("User-Agent", QString("cuteTube/%1 (Qt)").arg(Utils::versionNumberString()).toUtf8());
+    QNetworkReply *reply = this->networkAccessManager()->get(request);
+    this->connect(reply, SIGNAL(finished()), this, slot);
+    this->connect(this, SIGNAL(currentOperationCancelled()), reply, SLOT(deleteLater()));
+}
+
+void UrlGrabber::checkYouTubeVideoInfoPage() {
+    QNetworkReply* reply = qobject_cast<QNetworkReply*>(this->sender());
+
+    if (!reply) {
+        this->setBusy(false);
+        emit error(tr("Network error"));
+        return;
+    }
+
+    if (this->cancelled()) {
+        return;
+    }
+
+    QString response(reply->readAll());
+
+    if (!response.contains("url_encoded_fmt_stream_map=")) {
+        qDebug() << "No format map in YouTube video info page. Retrieving the web page";
+        this->getYouTubeVideoWebPage(reply->request().url().queryItemValue("video_id"), SLOT(checkYouTubeWebPage()));
+    }
+    else {
+        response = response.section("url_encoded_fmt_stream_map=", 1, 1);
+        QString separator = response.left(response.indexOf('%'));
+
+        if ((separator == "s") || (response.contains("%26s%3D"))) {
+            qDebug() << "YouTube video has encrypted signatures. Retrieving the web page";
+            this->getYouTubeVideoWebPage(reply->request().url().queryItemValue("video_id"), SLOT(checkYouTubeWebPage()));
+        }
+        else {
+            qDebug() << "YouTube video info OK. Parsing the page";
+            response.replace("%2C" + separator, "," + separator);
+            this->parseYouTubeVideoPage(QScriptValue(), response);
+        }
+    }
+
+    reply->deleteLater();
+}
+
+void UrlGrabber::getYouTubeVideoWebPage(const QString &id, const char *slot) {
     QUrl url("https://www.youtube.com/watch");
     url.addQueryItem("v", id);
     url.addQueryItem("gl", "US");
@@ -278,11 +334,11 @@ void UrlGrabber::getYouTubeVideoUrl(const QString &id) {
     QNetworkRequest request(url);
     request.setRawHeader("User-Agent", QString("cuteTube/%1 (Qt)").arg(Utils::versionNumberString()).toUtf8());
     QNetworkReply *reply = this->networkAccessManager()->get(request);
-    this->connect(reply, SIGNAL(finished()), this, SLOT(checkYouTubePageForEncryption()));
+    this->connect(reply, SIGNAL(finished()), this, slot);
     this->connect(this, SIGNAL(currentOperationCancelled()), reply, SLOT(deleteLater()));
 }
 
-void UrlGrabber::checkYouTubePageForEncryption() {
+void UrlGrabber::checkYouTubeWebPage() {
     QNetworkReply* reply = qobject_cast<QNetworkReply*>(this->sender());
 
     if (!reply) {
@@ -403,7 +459,7 @@ void UrlGrabber::parseDailymotionVideoPage() {
     else {
         emit gotVideoUrl(url, m_format);
     }
-    
+
     reply->deleteLater();
 }
 
@@ -535,19 +591,47 @@ void UrlGrabber::getAvailableVideoFormats(int service, const QString &id) {
 
 void UrlGrabber::getAvailableYouTubeVideoFormats(const QString &id) {
     this->setBusy(true, tr("Retrieving available video formats"));
-    QUrl url("https://www.youtube.com/watch");
-    url.addQueryItem("v", id);
-    url.addQueryItem("gl", "US");
-    url.addQueryItem("hl", "en");
-    url.addQueryItem("has_verified", "1");
-    QNetworkRequest request(url);
-    request.setRawHeader("User-Agent", QString("cuteTube/%1 (Qt)").arg(Utils::versionNumberString()).toUtf8());
-    QNetworkReply *reply = this->networkAccessManager()->get(request);
-    this->connect(reply, SIGNAL(finished()), this, SLOT(checkYouTubeVideoFormatsForEncryption()));
-    this->connect(this, SIGNAL(currentOperationCancelled()), reply, SLOT(deleteLater()));
+    this->getYouTubeVideoInfoPage(id, SLOT(checkYouTubeVideoInfoFormats()));
 }
 
-void UrlGrabber::checkYouTubeVideoFormatsForEncryption() {
+void UrlGrabber::checkYouTubeVideoInfoFormats() {
+    QNetworkReply* reply = qobject_cast<QNetworkReply*>(this->sender());
+
+    if (!reply) {
+        this->setBusy(false);
+        emit error(tr("Network error"));
+        return;
+    }
+
+    if (this->cancelled()) {
+        return;
+    }
+
+    QString response(reply->readAll());
+
+    if (!response.contains("url_encoded_fmt_stream_map=")) {
+        qDebug() << "No format map in YouTube video info page. Retrieving the web page";
+        this->getYouTubeVideoWebPage(reply->request().url().queryItemValue("video_id"), SLOT(checkYouTubeWebPageFormats()));
+    }
+    else {
+        response = response.section("url_encoded_fmt_stream_map=", 1, 1);
+        QString separator = response.left(response.indexOf('%'));
+
+        if ((separator == "s") || (response.contains("%26s%3D"))) {
+            qDebug() << "YouTube video has encrypted signatures. Retrieving the web page";
+            this->getYouTubeVideoWebPage(reply->request().url().queryItemValue("video_id"), SLOT(checkYouTubeWebPageFormats()));
+        }
+        else {
+            qDebug() << "YouTube video info OK. Parsing the page";
+            response.replace("%2C" + separator, "," + separator);
+            this->parseYouTubeVideoFormats(QScriptValue(), response);
+        }
+    }
+
+    reply->deleteLater();
+}
+
+void UrlGrabber::checkYouTubeWebPageFormats() {
     QNetworkReply* reply = qobject_cast<QNetworkReply*>(this->sender());
 
     if (!reply) {
@@ -609,42 +693,50 @@ void UrlGrabber::parseYouTubeVideoFormats(QScriptValue decryptionFunction, QStri
     }
 
     QVariantList formats;
+    QList<int> keys;
+#ifdef SYMBIAN_OS
+    keys << 37 << 22 << 18;
+#else
+    keys << 37 << 22 << 35 << 34 << 18;
+#endif
     QMap<int, QUrl> urlMap = this->getYouTubeVideoUrlMap(page, decryptionFunction);
 
-    foreach (int key, urlMap.keys()) {
-        QVariantMap format;
-        format["value"] = key;
-        format["url"] = urlMap.value(key);
+    foreach (int key, keys) {
+        if (urlMap.contains(key)) {
+            QVariantMap format;
+            format["value"] = key;
+            format["url"] = urlMap.value(key);
 
-        switch (key) {
-        case 37:
-            format["name"] = "1080P AVC1";
-            format["service"] = Services::YouTube;
-            formats << format;
-            break;
-        case 22:
-            format["name"] = "720P AVC1";
-            format["service"] = Services::YouTube;
-            formats << format;
-            break;
-#ifndef SYMBIAN_OS
-        case 35:
-            format["name"] = "480P FLV";
-            format["service"] = Services::YouTube;
-            formats << format;
-            break;
-        case 34:
-            format["name"] = "360P AVC1";
-            format["service"] = Services::YouTube;
-            formats << format;
-            break;
-#endif
-        case 18:
-            format["name"] = QString("%1 AVC1").arg(tr("Normal"));
-            format["service"] = Services::YouTube;
-            formats << format;
-        default:
-            break;
+            switch (key) {
+            case 37:
+                format["name"] = "1080P AVC1";
+                format["service"] = Services::YouTube;
+                formats << format;
+                break;
+            case 22:
+                format["name"] = "720P AVC1";
+                format["service"] = Services::YouTube;
+                formats << format;
+                break;
+    #ifndef SYMBIAN_OS
+            case 35:
+                format["name"] = "480P FLV";
+                format["service"] = Services::YouTube;
+                formats << format;
+                break;
+            case 34:
+                format["name"] = "360P AVC1";
+                format["service"] = Services::YouTube;
+                formats << format;
+                break;
+    #endif
+            case 18:
+                format["name"] = QString("%1 AVC1").arg(tr("Normal"));
+                format["service"] = Services::YouTube;
+                formats << format;
+            default:
+                break;
+            }
         }
     }
 
