@@ -57,14 +57,18 @@ private:
     void setCancelled(bool cancelled) { m_cancelled = cancelled; }
     QScriptValue getYouTubeDecryptionFunction(const QUrl &playerUrl);
     QMap<int, QUrl> getYouTubeVideoUrlMap(QString page, QScriptValue decryptionFunction = QScriptValue());
+    void getYouTubeVideoInfoPage(const QString &id, const char* slot);
+    void getYouTubeVideoWebPage(const QString &id, const char* slot);
 
 private slots:
-    void checkYouTubePageForEncryption();
+    void checkYouTubeVideoInfoPage();
+    void checkYouTubeWebPage();
     void parseYouTubeVideoPage(QScriptValue decryptionFunction = QScriptValue(), QString page = QString());
     void parseDailymotionVideoPage();
     void parseVimeoVideoPage();
     void checkVimeoVideoRedirect();
-    void checkYouTubeVideoFormatsForEncryption();
+    void checkYouTubeVideoInfoFormats();
+    void checkYouTubeWebPageFormats();
     void parseYouTubeVideoFormats(QScriptValue decryptionFunction = QScriptValue(), QString page = QString());
     void checkDailymotionVideoFormats();
     void checkVimeoVideoFormats();
