@@ -18,7 +18,7 @@ public:
     static QString localDateTimeFromString(const QString &dateTimeString, Qt::DateFormat = Qt::ISODate);
     static QString base64Id(const QString &artist, const QString &title);
     static QString serviceString(Services::VideoService service);
-    static QString reverseString(const QString &string);
+    static QString unescape(const QString &s);
     static void log(const QString &filePath, const QByteArray &message);
     static QString versionNumberString();
 };
