@@ -33,6 +33,17 @@ VideoLauncher* VideoLauncher::instance() {
 }
 
 void VideoLauncher::launchVideo(const QUrl &url) {
+#ifdef SYMBIAN_OS
+        QTemporaryFile *temp = new QTemporaryFile;
+        temp->setFileName(QDir::tempPath() + "/cutetube.ram");
+
+        if ((temp->open()) && (temp->write(QByteArray::fromPercentEncoding(url.toString().toUtf8())) > 0)) {
+            QDesktopServices::openUrl(QUrl::fromLocalFile(temp->fileName()));
+        }
+
+        temp->close();
+        QTimer::singleShot(5000, temp, SLOT(deleteLater()));
+#else
 #ifdef Q_OS_LINUX
     if (Settings::instance()->mediaPlayer() == "other") {
         QStringList args = Settings::instance()->mediaPlayerCommand().split(' ', QString::SkipEmptyParts);
@@ -47,7 +58,6 @@ void VideoLauncher::launchVideo(const QUrl &url) {
         QObject::connect(player, SIGNAL(finished(int, QProcess::ExitStatus)), player, SLOT(deleteLater()));
         player->start("/usr/bin/mplayer", args);
     }
-#endif
 #ifdef MEEGO_EDITION_HARMATTAN
     else if (Settings::instance()->mediaPlayer() == "mediaplayer") {
         ContentAction::Action::launcherAction("videosuiteinterface.desktop", QStringList(url.toString())).trigger();
@@ -61,16 +71,8 @@ void VideoLauncher::launchVideo(const QUrl &url) {
         QDBusConnection bus = QDBusConnection::sessionBus();
         QDBusInterface dbus_iface("com.nokia." + Settings::instance()->mediaPlayer(), "/com/nokia/" + Settings::instance()->mediaPlayer(), "com.nokia." + Settings::instance()->mediaPlayer(), bus);
         dbus_iface.call("mime_open", url.toString());
-#elif defined (SYMBIAN_OS)
-        QTemporaryFile *temp = new QTemporaryFile;
-        temp->setFileName(QDir::tempPath() + "/cutetube.ram");
-
-        if ((temp->open()) && (temp->write(QByteArray::fromPercentEncoding(url.toString().toUtf8())) > 0)) {
-            QDesktopServices::openUrl(QUrl::fromLocalFile(temp->fileName()));
-        }
-
-        temp->close();
-        QTimer::singleShot(5000, temp, SLOT(deleteLater()));
 #endif
     }
+#endif
+#endif
 }
