@@ -8,6 +8,7 @@
 #include <QMap>
 #include <QStringList>
 #include <QDebug>
+#include <QTimer>
 #ifdef QML_USER_INTERFACE
 #include <QDeclarativeEngine>
 #endif
@@ -198,9 +199,15 @@ QUrl YouTube::authUrl() const {
     return url;
 }
 
+void YouTube::clearLoginInfo() {
+    m_login.displayName = QString();
+    m_login.deviceCode = QString();
+    m_login.deviceInterval = 0;
+}
+
 void YouTube::signIn(const QString &displayName, const QString &code) {
     this->setBusy(true, tr("Signing in"));
-    m_user = displayName;
+    m_login.displayName = displayName;
     QUrl url("https://accounts.google.com/o/oauth2/token");
 
     QByteArray body("code=" + code.toUtf8() +
@@ -242,13 +249,170 @@ void YouTube::checkIfSignedIn() {
         }
         else {
             emit alert(tr("You are signed in to your YouTube account"));
-            emit signedIn(this->username(), token, refresh);
+            emit signedIn(m_login.displayName, token, refresh);
         }
     }
 
     reply->deleteLater();
 }
 
+void YouTube::signInFromDevice(const QString &displayName) {
+    this->setBusy(true, tr("Requesting authorisation code"));
+    m_login.displayName = displayName;
+    QUrl url("https://accounts.google.com/o/oauth2/device/code");
+    QByteArray body("scope=https://gdata.youtube.com&client_id=" + CLIENT_ID);
+    QNetworkRequest request(url);
+    request.setRawHeader("User-Agent", QString("cuteTube/%1 (Qt)").arg(Utils::versionNumberString()).toUtf8());
+    request.setHeader(QNetworkRequest::ContentTypeHeader, "application/x-www-form-urlencoded");
+    QNetworkReply *reply = this->networkAccessManager()->post(request, body);
+    this->connect(reply, SIGNAL(finished()), this, SLOT(checkDeviceSignInInfo()));
+    this->connect(this, SIGNAL(currentOperationCancelled()), reply, SLOT(deleteLater()));
+}
+
+void YouTube::checkDeviceSignInInfo() {
+    this->setBusy(false);
+    QNetworkReply* reply = qobject_cast<QNetworkReply*>(this->sender());
+
+    if (!reply) {
+        emit error(tr("Network error"));
+        return;
+    }
+
+    QString response(reply->readAll());
+    qDebug() << response;
+    bool ok;
+    QVariantMap result = Json::parse(response, ok).toMap();
+
+    if (!ok) {
+        this->clearLoginInfo();
+        emit error(tr("Cannot parse server response"));
+    }
+    else {
+        QString deviceCode = result.value("device_code").toString();
+        QString userCode = result.value("user_code").toString();
+        QString verificationUrl = result.value("verification_url").toString();
+        int interval = result.value("interval").toInt();
+
+        if ((!deviceCode.isEmpty()) && (!userCode.isEmpty()) && (!verificationUrl.isEmpty()) && (interval > 0)) {
+            m_login.deviceCode = deviceCode;
+            m_login.deviceInterval = interval * 1100;
+            this->setBusy(true, QString("%1\n\n%2\n\n%3:\n\n%4").arg(tr("Please visit")).arg(verificationUrl).arg(tr("using your web browser and enter the following")).arg(userCode));
+            QTimer::singleShot(m_login.deviceInterval, this, SLOT(pollServerForDeviceToken()));
+        }
+        else {
+            this->clearLoginInfo();
+            QString errorString = result.value("error").toString();
+            emit error(errorString.isEmpty() ? tr("Unable to obtain authorisation code") : errorString);
+        }
+    }
+
+    reply->deleteLater();
+}
+
+void YouTube::pollServerForDeviceToken() {
+    if (m_login.deviceCode.isEmpty()) {
+        this->setBusy(false);
+        emit error(tr("No device code for authorisation"));
+        return;
+    }
+
+    QUrl url("https://accounts.google.com/o/oauth2/token");
+
+    QByteArray body("client_id=" + CLIENT_ID +
+                    "&client_secret=" + CLIENT_SECRET +
+                    "&grant_type=http://oauth.net/grant_type/device/1.0" +
+                    "&code=" + m_login.deviceCode.toUtf8());
+
+    QNetworkRequest request(url);
+    request.setRawHeader("User-Agent", QString("cuteTube/%1 (Qt)").arg(Utils::versionNumberString()).toUtf8());
+    request.setHeader(QNetworkRequest::ContentTypeHeader, "application/x-www-form-urlencoded");
+    QNetworkReply *reply = this->networkAccessManager()->post(request, body);
+    this->connect(reply, SIGNAL(finished()), this, SLOT(checkDeviceToken()));
+    this->connect(this, SIGNAL(currentOperationCancelled()), reply, SLOT(deleteLater()));
+}
+
+void YouTube::checkDeviceToken() {
+    QNetworkReply* reply = qobject_cast<QNetworkReply*>(this->sender());
+
+    if (!reply) {
+        this->setBusy(false);
+        this->clearLoginInfo();
+        emit error(tr("Network error"));
+        return;
+    }
+
+    QString response(reply->readAll());
+    qDebug() << response;
+    bool ok;
+    QVariantMap result = Json::parse(response, ok).toMap();
+
+    if (!ok) {
+        this->setBusy(false);
+        this->clearLoginInfo();
+        emit error(tr("Cannot parse server response"));
+    }
+    else {
+        QString token = result.value("access_token").toString();
+        QString refresh = result.value("refresh_token").toString();
+
+        if ((token.isEmpty()) || (refresh.isEmpty())) {
+            QString errorString = result.value("error").toString();
+
+            if (errorString == "authorization_pending") {
+                QTimer::singleShot(m_login.deviceInterval, this, SLOT(pollServerForDeviceToken()));
+            }
+            else if (errorString == "slow_down") {
+                m_login.deviceInterval = m_login.deviceInterval * 2;
+                QTimer::singleShot(m_login.deviceInterval, this, SLOT(pollServerForDeviceToken()));
+            }
+            else {
+                this->setBusy(false);
+                this->clearLoginInfo();
+                emit error(errorString.isEmpty() ? tr("Unable to obtain access token") : errorString);
+            }
+        }
+        else {
+            this->setBusy(false);
+            emit alert(tr("You are signed in to your YouTube account"));
+            emit signedIn(m_login.displayName, token, refresh);
+        }
+    }
+
+    reply->deleteLater();
+}
+
+void YouTube::signOut() {
+    this->setBusy(true, tr("Signing out"));
+    QUrl url("https://accounts.google.com/o/oauth2/revoke");
+    url.addQueryItem("token", this->accessToken());
+    QNetworkRequest request(url);
+    QNetworkReply *reply = this->networkAccessManager()->get(request);
+    this->connect(reply, SIGNAL(finished()), this, SLOT(checkIfSignedOut()));
+    this->connect(this, SIGNAL(currentOperationCancelled()), reply, SLOT(deleteLater()));
+}
+
+void YouTube::checkIfSignedOut() {
+    this->setBusy(false);
+    QNetworkReply* reply = qobject_cast<QNetworkReply*>(this->sender());
+
+    if (!reply) {
+        emit error(tr("Network error"));
+        return;
+    }
+
+    int statusCode = reply->attribute(QNetworkRequest::HttpStatusCodeAttribute).toInt();
+
+    if (statusCode == 200) {
+        this->setAccount();
+        emit info(tr("You have signed out of your YouTube account"));
+    }
+    else {
+        emit error(tr("Unable to sign out of your YouTube account. Please visit the YouTube website to revoke access"));
+    }
+
+    reply->deleteLater();
+}
+
 void YouTube::refreshAccessToken() {
     QUrl url("https://accounts.google.com/o/oauth2/token");
 
