@@ -21,7 +21,7 @@ YouTubeAccountsListModel::YouTubeAccountsListModel(QObject *parent) :
     this->connect(YouTube::instance(), SIGNAL(signedIn(QString,QString,QString)), this, SLOT(addAccount(QString,QString,QString)));
     this->connect(this, SIGNAL(accountSelected(QString,QString,QString)), YouTube::instance(), SLOT(setAccount(QString,QString,QString)));
     this->connect(this, SIGNAL(accountAdded(QString,QString,QString)), YouTube::instance(), SLOT(setAccount(QString,QString,QString)));
-    this->connect(this, SIGNAL(accountDeleted()), YouTube::instance(), SLOT(setAccount()));
+    this->connect(this, SIGNAL(accountDeleted()), YouTube::instance(), SLOT(signOut()));
     this->connect(this, SIGNAL(info(QString)), Notifications::instance(), SLOT(onInfo(QString)));
     this->connect(this, SIGNAL(error(QString)), Notifications::instance(), SLOT(onError(QString)));
 }
@@ -37,10 +37,10 @@ void YouTubeAccountsListModel::setActiveAccount(int row) {
     QSqlField tokenField("token", QVariant::String);
     QSqlField refreshField("refresh", QVariant::String);
     QSqlField activeField("active", QVariant::Int);
-    nameField.setValue(data(index(row, 0), DisplayNameRole));
-    usernameField.setValue(data(index(row, 0), UsernameRole));
-    tokenField.setValue(data(index(row, 0), AccessTokenRole));
-    refreshField.setValue(data(index(row, 0), RefreshTokenRole));
+    nameField.setValue(this->data(this->index(row, 0), DisplayNameRole));
+    usernameField.setValue(this->data(this->index(row, 0), UsernameRole));
+    tokenField.setValue(this->data(this->index(row, 0), AccessTokenRole));
+    refreshField.setValue(this->data(this->index(row, 0), RefreshTokenRole));
     activeField.setValue(1);
 
     QSqlRecord rec;
