@@ -15,12 +15,14 @@ YouTubeUserPlaylistListModel::YouTubeUserPlaylistListModel(QObject *parent) :
     roles[PlaylistIdRole] = "playlistId";
     roles[TitleRole] = "title";
     roles[ArtistRole] = "artist";
+    roles[ArtistAvatarUrlRole] = "artistAvatarUrl";
     roles[DateRole] = "date";
     roles[VideoCountRole] = "videoCount";
 #ifndef QML_USER_INTERFACE
     roles[ThumbnailRole] = "thumbnail";
 #endif
     roles[ThumbnailUrlRole] = "thumbnailUrl";
+    roles[LargeThumbnailUrlRole] = "largeThumbnailUrl";
     roles[DescriptionRole] = "description";
     this->setRoleNames(roles);
 #ifndef QML_USER_INTERFACE
@@ -74,6 +76,8 @@ QVariant YouTubeUserPlaylistListModel::data(const QModelIndex &index, int role)
         return YouTube::instance()->playlists()->at(index.row()).data()->title();
     case ArtistRole:
         return YouTube::instance()->playlists()->at(index.row()).data()->artist();
+    case ArtistAvatarUrlRole:
+        return YouTube::instance()->playlists()->at(index.row()).data()->artistAvatarUrl();
     case DateRole:
         return YouTube::instance()->playlists()->at(index.row()).data()->date();
     case VideoCountRole:
@@ -84,6 +88,8 @@ QVariant YouTubeUserPlaylistListModel::data(const QModelIndex &index, int role)
 #endif
     case ThumbnailUrlRole:
         return YouTube::instance()->playlists()->at(index.row()).data()->thumbnailUrl();
+    case LargeThumbnailUrlRole:
+        return YouTube::instance()->playlists()->at(index.row()).data()->largeThumbnailUrl();
     case DescriptionRole:
         return YouTube::instance()->playlists()->at(index.row()).data()->description();
     default:
