@@ -43,7 +43,7 @@ DailymotionPlaylistVideosWindow::DailymotionPlaylistVideosWindow(QSharedPointer<
     m_addToQueueContextAction(m_contextMenu->addAction(tr("Add to playback queue"), this, SLOT(queueVideo()))),
     m_videoDownloadContextAction(m_contextMenu->addAction(tr("Download"), this, SLOT(addVideoDownload()))),
     m_audioDownloadContextAction(m_contextMenu->addAction(tr("Download (audio)"), this, SLOT(addAudioDownload()))),
-    m_titleLabel(new QLabel(QString("<p style='font-size:32px;'>%1</p>").arg(m_playlist.data()->title()))),
+    m_titleLabel(new QLabel(QString("<p style='font-size:32px;'>%1</p>").arg(m_playlist.data()->title()), this)),
     m_descriptionLabel(new QLabel(m_playlist.data()->description().isEmpty() ? tr("No description") : m_playlist.data()->description(), this)),
     m_dateLabel(new QLabel(QString("%1 - %2").arg(m_playlist.data()->date()).arg(m_playlist.data()->artist()), this)),
     m_thumbnail(new ThumbnailLabel(this)),
