@@ -8,6 +8,7 @@
 #include <QPushButton>
 #include <QScrollArea>
 #include <QGridLayout>
+#include <QMaemo5Style>
 
 DailymotionProfileTab::DailymotionProfileTab(const QString &userId, QWidget *parent) :
     AbstractTab(parent),
@@ -16,7 +17,7 @@ DailymotionProfileTab::DailymotionProfileTab(const QString &userId, QWidget *par
     m_viewsLabel(new QLabel(this)),
     m_locationLabel(new QLabel(this)),
     m_descriptionLabel(new QLabel(this)),
-    m_noProfileLabel(new QLabel(QString("<p style='color:#4d4d4d;font-size:40px;'><center><b>%1</b></center></p>").arg(tr("No profile found")), this)),
+    m_noProfileLabel(new QLabel(QString("<p style='color:%1;font-size:40px;'><center><b>%2</b></center></p>").arg(QMaemo5Style::standardColor("SecondaryTextColor").name()).arg(tr("No profile found")), this)),
     m_subscriptionButton(new QPushButton(tr("Subscribe"))),
     m_scrollArea(new QScrollArea(this)),
     m_grid(new QGridLayout(this))
