@@ -4,7 +4,6 @@
 #include "abstracttab.h"
 #include "../base/useritem.h"
 
-class Session;
 class SeparatorLabel;
 class AvatarLabel;
 class QLabel;
@@ -17,7 +16,7 @@ class DailymotionProfileTab : public AbstractTab
     Q_OBJECT
 
 public:
-    explicit DailymotionProfileTab(Session *session, const QString &userId, QWidget *parent = 0);
+    explicit DailymotionProfileTab(const QString &userId, QWidget *parent = 0);
 
 private:
     void setLandscapeLayout();
@@ -31,7 +30,6 @@ private slots:
     void onSubscribedChanged(bool subscribed);
 
 private:
-    Session *m_session;
     QSharedPointer<UserItem> m_user;
     AvatarLabel *m_avatar;
     QLabel *m_channelLabel;
