@@ -4,7 +4,6 @@
 #include "abstracttab.h"
 #include "../base/groupitem.h"
 
-class Session;
 class ListView;
 class DailymotionUserGroupListModel;
 class QLabel;
@@ -17,7 +16,7 @@ class DailymotionUserGroupListTab : public AbstractTab
 {
     Q_OBJECT
 public:
-    explicit DailymotionUserGroupListTab(Session *session, QWidget *parent = 0);
+    explicit DailymotionUserGroupListTab(QWidget *parent = 0);
 
 private:
     void setLandscapeLayout();
@@ -32,7 +31,6 @@ private slots:
     void leaveGroup();
 
 private:
-    Session *m_session;
     ListView *m_listView;
     DailymotionUserGroupListModel *m_model;
     QMenu *m_contextMenu;
