@@ -4,7 +4,6 @@
 #include "abstracttab.h"
 #include "../base/playlistitem.h"
 
-class Session;
 class ListView;
 class DailymotionUserPlaylistListModel;
 class QLabel;
@@ -17,7 +16,7 @@ class DailymotionUserPlaylistListTab : public AbstractTab
 {
     Q_OBJECT
 public:
-    explicit DailymotionUserPlaylistListTab(Session *session, QWidget *parent = 0);
+    explicit DailymotionUserPlaylistListTab(QWidget *parent = 0);
 
 private:
     void setLandscapeLayout();
@@ -33,7 +32,6 @@ private slots:
     void showNewPlaylistDialog();
 
 private:
-    Session *m_session;
     ListView *m_listView;
     DailymotionUserPlaylistListModel *m_model;
     QMenu *m_contextMenu;
