@@ -3,17 +3,16 @@
 
 #include "abstractdialog.h"
 
-class Settings;
 class QCheckBox;
 class QDialogButtonBox;
 class QScrollArea;
 class QGridLayout;
 
-class DownloadQualityDialog : public AbstractDialog
+class DownloadFormatDialog : public AbstractDialog
 {
     Q_OBJECT
 public:
-    explicit DownloadQualityDialog(Settings *settings, QWidget *parent = 0);
+    explicit DownloadFormatDialog(QWidget *parent = 0);
 
 private slots:
     void saveSettings();
@@ -24,7 +23,6 @@ private:
     void setPortraitLayout();
 
 private:
-    Settings *m_settings;
     QCheckBox *m_youtube1080Checkbox;
     QCheckBox *m_youtube720Checkbox;
     QCheckBox *m_youtube480Checkbox;
