@@ -31,13 +31,19 @@
 #include "archivewindow.h"
 #include "navbutton.h"
 #include "../base/feedurls.h"
-#include "../base/session.h"
+#include "../base/sharing.h"
+#include "../base/youtube.h"
+#include "../base/dailymotion.h"
+#include "../base/vimeo.h"
+#include "../base/windowstack.h"
+#include "../base/settings.h"
+#include "../base/clipboardmonitor.h"
 #include <QGridLayout>
 #include <QAction>
 #include <QMenuBar>
 
-HomeWindow::HomeWindow(Session *session, QWidget *parent) :
-    StackedWindow(session, parent),
+HomeWindow::HomeWindow(QWidget *parent) :
+    StackedWindow(parent),
     m_myChannelButton(new NavButton(tr("My Channel"), ":/images/mychannel.png", this)),
     m_latestButton(new NavButton(tr("Latest Videos"), ":/images/latest.png", this)),
     m_categoriesButton(new NavButton(tr("Categories"), ":/images/categories.png", this)),
@@ -67,9 +73,10 @@ HomeWindow::HomeWindow(Session *session, QWidget *parent) :
     this->connect(m_transfersButton, SIGNAL(clicked()), this, SLOT(showTransfers()));
     this->connect(m_archiveButton, SIGNAL(clicked()), this, SLOT(showArchive()));
     this->connect(m_accountsButton, SIGNAL(clicked()), this, SLOT(showAccounts()));
-    this->connect(m_session->youtube(), SIGNAL(requestToLinkGoogleAccount()), this, SLOT(showLinkGoogleAccountDialog()));
-    this->connect(m_session->sharing(), SIGNAL(reauthenticateForFacebook()), this, SLOT(showFacebookAuthDialog()));
-    this->connect(m_session->sharing(), SIGNAL(reauthenticateForTwitter()), this, SLOT(showTwitterAuthDialog()));
+    this->connect(YouTube::instance(), SIGNAL(requestToLinkGoogleAccount()), this, SLOT(showLinkGoogleAccountDialog()));
+    this->connect(Sharing::instance(), SIGNAL(reauthenticateForFacebook()), this, SLOT(showFacebookAuthDialog()));
+    this->connect(Sharing::instance(), SIGNAL(reauthenticateForTwitter()), this, SLOT(showTwitterAuthDialog()));
+    this->connect(ClipboardMonitor::instance(), SIGNAL(gotClipboardUrl(QString)), this, SLOT(display(QString)));
 
     this->onOrientationChanged();
 }
@@ -134,7 +141,7 @@ void HomeWindow::setPortraitLayout() {
 }
 
 void HomeWindow::showSettingsDialog() {
-    SettingsDialog *dialog = new SettingsDialog(m_session, this);
+    SettingsDialog *dialog = new SettingsDialog(this);
     dialog->open();
 }
 
@@ -144,10 +151,20 @@ void HomeWindow::showAboutDialog() {
 }
 
 void HomeWindow::showMyChannel(Services::VideoService service) {
-    if (service == Services::NoService) {
-        bool signedInToYouTube = m_session->youtube()->userSignedIn();
-        bool signedInToDailymotion = m_session->dailymotion()->userSignedIn();
-        bool signedInToVimeo = m_session->vimeo()->userSignedIn();
+    switch (service) {
+    case Services::YouTube:
+        this->showYouTubeChannel();
+        return;
+    case Services::Dailymotion:
+        this->showDailymotionChannel();
+        return;
+    case Services::Vimeo:
+        this->showVimeoChannel();
+        return;
+    default:
+        bool signedInToYouTube = YouTube::instance()->userSignedIn();
+        bool signedInToDailymotion = Dailymotion::instance()->userSignedIn();
+        bool signedInToVimeo = Vimeo::instance()->userSignedIn();
         int accounts = 0;
 
         if (signedInToYouTube) {
@@ -177,21 +194,14 @@ void HomeWindow::showMyChannel(Services::VideoService service) {
         else {
             this->showSignInDialog();
         }
-    }
-    else if (service == Services::YouTube) {
-        this->showYouTubeChannel();
-    }
-    else if (service == Services::Dailymotion) {
-        this->showDailymotionChannel();
-    }
-    else if (service == Services::Vimeo) {
-        this->showVimeoChannel();
+
+        return;
     }
 }
 
 void HomeWindow::showYouTubeChannel() {
-    if (m_session->youtube()->userSignedIn()) {
-        YouTubeMyChannelWindow *window = new YouTubeMyChannelWindow(m_session, this);
+    if (YouTube::instance()->userSignedIn()) {
+        YouTubeMyChannelWindow *window = new YouTubeMyChannelWindow(this);
         window->show();
     }
     else {
@@ -200,8 +210,8 @@ void HomeWindow::showYouTubeChannel() {
 }
 
 void HomeWindow::showDailymotionChannel() {
-    if (m_session->dailymotion()->userSignedIn()) {
-        DailymotionMyChannelWindow *window = new DailymotionMyChannelWindow(m_session, this);
+    if (Dailymotion::instance()->userSignedIn()) {
+        DailymotionMyChannelWindow *window = new DailymotionMyChannelWindow(this);
         window->show();
     }
     else {
@@ -210,8 +220,8 @@ void HomeWindow::showDailymotionChannel() {
 }
 
 void HomeWindow::showVimeoChannel() {
-    if (m_session->vimeo()->userSignedIn()) {
-        VimeoMyChannelWindow *window = new VimeoMyChannelWindow(m_session, this);
+    if (Vimeo::instance()->userSignedIn()) {
+        VimeoMyChannelWindow *window = new VimeoMyChannelWindow(this);
         window->show();
     }
     else {
@@ -220,10 +230,21 @@ void HomeWindow::showVimeoChannel() {
 }
 
 void HomeWindow::showLatestVideos(Services::VideoService service) {
-    if (service == Services::NoService) {
-        bool signedInToYouTube = m_session->youtube()->userSignedIn();
-        bool signedInToDailymotion = m_session->dailymotion()->userSignedIn();
-        bool signedInToVimeo = m_session->vimeo()->userSignedIn();
+    switch (service) {
+    case Services::YouTube:
+        this->showLatestYouTubeVideos();
+        return;
+    case Services::Dailymotion:
+        this->showLatestDailymotionVideos();
+        return;
+    case Services::Vimeo:
+        this->showLatestVimeoVideos();
+        return;
+    default:
+    {
+        bool signedInToYouTube = YouTube::instance()->userSignedIn();
+        bool signedInToDailymotion = Dailymotion::instance()->userSignedIn();
+        bool signedInToVimeo = Vimeo::instance()->userSignedIn();
         int accounts = 0;
 
         if (signedInToYouTube) {
@@ -254,20 +275,13 @@ void HomeWindow::showLatestVideos(Services::VideoService service) {
             this->showSignInDialog();
         }
     }
-    else if (service == Services::YouTube) {
-        this->showLatestYouTubeVideos();
-    }
-    else if (service == Services::Dailymotion) {
-        this->showLatestDailymotionVideos();
-    }
-    else if (service == Services::Vimeo) {
-        this->showLatestVimeoVideos();
+        return;
     }
 }
 
 void HomeWindow::showLatestYouTubeVideos() {
-    if (m_session->youtube()->userSignedIn()) {
-        YouTubeVideoListWindow *window = new YouTubeVideoListWindow(m_session, this);
+    if (YouTube::instance()->userSignedIn()) {
+        YouTubeVideoListWindow *window = new YouTubeVideoListWindow(this);
         window->setVideoFeed(YOUTUBE_NEW_SUBSCRIPTION_VIDEOS_FEED);
         window->setWindowTitle(tr("Latest subscription videos"));
         window->show();
@@ -278,8 +292,8 @@ void HomeWindow::showLatestYouTubeVideos() {
 }
 
 void HomeWindow::showLatestDailymotionVideos() {
-    if (m_session->dailymotion()->userSignedIn()) {
-        DailymotionVideoListWindow *window = new DailymotionVideoListWindow(m_session, this);
+    if (Dailymotion::instance()->userSignedIn()) {
+        DailymotionVideoListWindow *window = new DailymotionVideoListWindow(this);
         window->setVideoFeed(DAILYMOTION_NEW_SUBSCRIPTION_VIDEOS_FEED);
         window->setWindowTitle(tr("Latest subscription videos"));
         window->show();
@@ -290,8 +304,8 @@ void HomeWindow::showLatestDailymotionVideos() {
 }
 
 void HomeWindow::showLatestVimeoVideos() {
-    if (m_session->vimeo()->userSignedIn()) {
-        VimeoVideoListWindow *window = new VimeoVideoListWindow(m_session, this);
+    if (Vimeo::instance()->userSignedIn()) {
+        VimeoVideoListWindow *window = new VimeoVideoListWindow(this);
         window->setVideoFeed(VIMEO_NEW_SUBSCRIPTION_VIDEOS_FEED);
         window->setWindowTitle(tr("Latest subscription videos"));
         window->show();
@@ -302,52 +316,76 @@ void HomeWindow::showLatestVimeoVideos() {
 }
 
 void HomeWindow::showCategoriesDialog(Services::VideoService service) {
-    if (service == Services::NoService) {
-        VideoServiceDialog *dialog = new VideoServiceDialog(this);
-        dialog->open();
-        this->connect(dialog, SIGNAL(valueChanged(Services::VideoService)), this, SLOT(showCategoriesDialog(Services::VideoService)));
+    switch (service) {
+    case Services::NoService:
+    {
+        VideoServiceDialog *serviceDialog = new VideoServiceDialog(this);
+        serviceDialog->open();
+        this->connect(serviceDialog, SIGNAL(valueChanged(Services::VideoService)), this, SLOT(showCategoriesDialog(Services::VideoService)));
     }
-    else if (service == Services::YouTube) {
-        YouTubeCategoriesDialog *dialog = new YouTubeCategoriesDialog(this);
-        dialog->open();
-        this->connect(dialog, SIGNAL(categoryChosen(Services::VideoService,QString,QString)), this, SLOT(showCategoryVideos(Services::VideoService,QString,QString)));
+        return;
+    case Services::YouTube:
+    {
+        YouTubeCategoriesDialog *youtubeDialog = new YouTubeCategoriesDialog(this);
+        youtubeDialog->open();
+        this->connect(youtubeDialog, SIGNAL(categoryChosen(Services::VideoService,QString,QUrl)), this, SLOT(showCategoryVideos(Services::VideoService,QString,QUrl)));
     }
-    else if (service == Services::Dailymotion) {
-        DailymotionCategoriesDialog *dialog = new DailymotionCategoriesDialog(this);
-        dialog->open();
-        this->connect(dialog, SIGNAL(categoryChosen(Services::VideoService,QString,QString)), this, SLOT(showCategoryVideos(Services::VideoService,QString,QString)));
+        return;
+    case Services::Dailymotion:
+    {
+        DailymotionCategoriesDialog *dailymotionDialog = new DailymotionCategoriesDialog(this);
+        dailymotionDialog->open();
+        this->connect(dailymotionDialog, SIGNAL(categoryChosen(Services::VideoService,QString,QUrl)), this, SLOT(showCategoryVideos(Services::VideoService,QString,QUrl)));
     }
-    else if (service == Services::Vimeo) {
-        VimeoCategoriesDialog *dialog = new VimeoCategoriesDialog(this);
-        dialog->open();
-        this->connect(dialog, SIGNAL(categoryChosen(Services::VideoService,QString,QString)), this, SLOT(showCategoryVideos(Services::VideoService,QString,QString)));
+        return;
+    case Services::Vimeo:
+    {
+        VimeoCategoriesDialog *vimeoDialog = new VimeoCategoriesDialog(this);
+        vimeoDialog->open();
+        this->connect(vimeoDialog, SIGNAL(categoryChosen(Services::VideoService,QString,QUrl)), this, SLOT(showCategoryVideos(Services::VideoService,QString,QUrl)));
+    }
+        return;
+    default:
+        qWarning() << "HomeWindow::showCategoriesDialog(): Invalid service";
+        return;
     }
 }
 
-void HomeWindow::showCategoryVideos(Services::VideoService service, const QString &title, const QString &feed) {
-    if (service == Services::YouTube) {
-        YouTubeVideoListWindow *window = new YouTubeVideoListWindow(m_session, this);
-        window->setVideoFeed(feed);
-        window->setWindowTitle(title);
-        window->show();
+void HomeWindow::showCategoryVideos(Services::VideoService service, const QString &title, const QUrl &feed) {
+    switch (service) {
+    case Services::YouTube:
+    {
+        YouTubeVideoListWindow *youtubeWindow = new YouTubeVideoListWindow(this);
+        youtubeWindow->setVideoFeed(feed);
+        youtubeWindow->setWindowTitle(title);
+        youtubeWindow->show();
     }
-    else if (service == Services::Dailymotion) {
-        DailymotionVideoListWindow *window = new DailymotionVideoListWindow(m_session, this);
-        window->setVideoFeed(feed);
-        window->setWindowTitle(title);
-        window->show();
+        return;
+    case Services::Dailymotion:
+    {
+        DailymotionVideoListWindow *dailymotionWindow = new DailymotionVideoListWindow(this);
+        dailymotionWindow->setVideoFeed(feed);
+        dailymotionWindow->setWindowTitle(title);
+        dailymotionWindow->show();
     }
-    else if (service == Services::Vimeo) {
-        VimeoVideoListWindow *window = new VimeoVideoListWindow(m_session, this);
-        window->setVideoFeed(feed);
-        window->setWindowTitle(title);
-        window->show();
+        return;
+    case Services::Vimeo:
+    {
+        VimeoVideoListWindow *vimeoWindow = new VimeoVideoListWindow(this);
+        vimeoWindow->setVideoFeed(feed);
+        vimeoWindow->setWindowTitle(title);
+        vimeoWindow->show();
+    }
+        return;
+    default:
+        qWarning() << "HomeWindow::showCategoryVideos(): Invalid service";
+        return;
     }
 }
 
 void HomeWindow::showSocialVideos() {
-    if ((m_session->sharing()->userSignedInToFacebook()) || (m_session->sharing()->userSignedInToTwitter())) {
-        SocialVideoListWindow *window = new SocialVideoListWindow(m_session, this);
+    if ((Sharing::instance()->userSignedInToFacebook()) || (Sharing::instance()->userSignedInToTwitter())) {
+        SocialVideoListWindow *window = new SocialVideoListWindow(this);
         window->show();
     }
     else {
@@ -356,122 +394,205 @@ void HomeWindow::showSocialVideos() {
 }
 
 void HomeWindow::showSearchDialog() {
-    SearchDialog *dialog = new SearchDialog(m_session, this);
+    SearchDialog *dialog = new SearchDialog(this);
     dialog->open();
 
     this->connect(dialog, SIGNAL(search(QString)), this, SLOT(search(QString)));
-    this->connect(dialog, SIGNAL(goToVideo(QString)), this, SLOT(displayVideo(QString)));
+    this->connect(dialog, SIGNAL(goToVideo(QString)), this, SLOT(display(QString)));
 }
 
 void HomeWindow::search(const QString &query) {
-    if (m_session->settings()->searchSite() == Services::YouTube) {
-        if (m_session->settings()->searchType() == Queries::Videos) {
-            YouTubeVideoListWindow *window = new YouTubeVideoListWindow(m_session, this);
-            window->search(query, m_session->settings()->searchOrder(), m_session->settings()->searchTime(), m_session->settings()->searchDuration(), m_session->settings()->languageFilter());
-            window->show();
-        }
-        else if (m_session->settings()->searchType() == Queries::Playlists) {
-            YouTubePlaylistListWindow *window = new YouTubePlaylistListWindow(m_session, this);
-            window->search(query, m_session->settings()->searchOrder());
-            window->show();
-        }
-        else if (m_session->settings()->searchType() == Queries::Users) {
-            YouTubeUserListWindow *window = new YouTubeUserListWindow(m_session, this);
-            window->search(query);
-            window->show();
-        }
-    }
-    else if (m_session->settings()->searchSite() == Services::Dailymotion) {
-        if (m_session->settings()->searchType() == Queries::Videos) {
-            DailymotionVideoListWindow *window = new DailymotionVideoListWindow(m_session, this);
-            window->search(query, m_session->settings()->searchOrder(), m_session->settings()->languageFilter());
-            window->show();
-        }
-        else if (m_session->settings()->searchType() == Queries::Playlists) {
-            DailymotionPlaylistListWindow *window = new DailymotionPlaylistListWindow(m_session, this);
-            window->search(query, m_session->settings()->searchOrder());
-            window->show();
-        }
-        else if (m_session->settings()->searchType() == Queries::Users) {
-            DailymotionUserListWindow *window = new DailymotionUserListWindow(m_session, this);
-            window->search(query);
-            window->show();
-        }
-        else if (m_session->settings()->searchType() == Queries::Groups) {
-            DailymotionGroupListWindow *window = new DailymotionGroupListWindow(m_session, this);
-            window->search(query, m_session->settings()->searchOrder());
-            window->show();
-        }
-    }
-    else if (m_session->settings()->searchSite() == Services::Vimeo) {
-        VimeoVideoListWindow *window = new VimeoVideoListWindow(m_session, this);
-        window->search(query, m_session->settings()->searchOrder());
-        window->show();
+    this->search(query,
+                 Settings::instance()->searchSite(),
+                 Settings::instance()->searchType(),
+                 Settings::instance()->searchOrder(),
+                 Settings::instance()->searchTime(),
+                 Settings::instance()->searchDuration(),
+                 Settings::instance()->languageFilter());
+}
+
+void HomeWindow::search(const QString &query, Services::VideoService service, Queries::QueryType type, Queries::QueryOrder order, Queries::TimeFilter timeFilter, Queries::DurationFilter durationFilter, const QString &languageFilter) {
+    switch (type) {
+    case Queries::Videos:
+        this->videoSearch(query, service, order, timeFilter, durationFilter, languageFilter);
+        return;
+    case Queries::Playlists:
+        this->playlistSearch(query, service, order);
+        return;
+    case Queries::Users:
+        this->userSearch(query, service);
+        return;
+    case Queries::Groups:
+        this->groupSearch(query, service, order);
+        return;
+    default:
+        qWarning() << "HomeWindow::search(): Invalid query type.";
+        return;
     }
 }
 
-void HomeWindow::displayVideo(const QString &url) {
-    m_session->unwindWindowStack();
+void HomeWindow::videoSearch(const QString &query, Services::VideoService service, Queries::QueryOrder order, Queries::TimeFilter timeFilter, Queries::DurationFilter durationFilter, const QString &languageFilter) {
+    switch (service) {
+    case Services::YouTube:
+    {
+        YouTubeVideoListWindow *youtubeWindow = new YouTubeVideoListWindow(this);
+        youtubeWindow->search(query, order, timeFilter, durationFilter, languageFilter);
+        youtubeWindow->show();
+    }
+        return;
+    case Services::Dailymotion:
+    {
+        DailymotionVideoListWindow *dailymotionWindow = new DailymotionVideoListWindow(this);
+        dailymotionWindow->search(query, order, languageFilter);
+        dailymotionWindow->show();
+    }
+        return;
+    case Services::Vimeo:
+    {
+        VimeoVideoListWindow *vimeoWindow = new VimeoVideoListWindow(this);
+        vimeoWindow->search(query, order);
+        vimeoWindow->show();
+    }
+        return;
+    default:
+        qWarning() << "HomeWindow::videoSearch(): Invalid service";
+        return;
+    }
+}
+
+void HomeWindow::playlistSearch(const QString &query, Services::VideoService service, Queries::QueryOrder order) {
+    switch (service) {
+    case Services::YouTube:
+    {
+        YouTubePlaylistListWindow *youtubeWindow = new YouTubePlaylistListWindow(this);
+        youtubeWindow->search(query, order);
+        youtubeWindow->show();
+    }
+        return;
+    case Services::Dailymotion:
+    {
+        DailymotionPlaylistListWindow *dailymotionWindow = new DailymotionPlaylistListWindow(this);
+        dailymotionWindow->search(query, order);
+        dailymotionWindow->show();
+    }
+        return;
+    default:
+        qWarning() << "HomeWindow::playlistSearch(): Invalid service";
+        return;
+    }
+}
+
+void HomeWindow::groupSearch(const QString &query, Services::VideoService service, Queries::QueryOrder order) {
+    switch (service) {
+    case Services::Dailymotion:
+    {
+        DailymotionGroupListWindow *window = new DailymotionGroupListWindow(this);
+        window->search(query, order);
+        window->show();
+    }
+        return;
+    default:
+        qWarning() << "HomeWindow::groupSearch(): Invalid service";
+        return;
+    }
+}
+
+void HomeWindow::userSearch(const QString &query, Services::VideoService service) {
+    switch (service) {
+    case Services::YouTube:
+    {
+        YouTubeUserListWindow *youtubeWindow = new YouTubeUserListWindow(this);
+        youtubeWindow->search(query);
+        youtubeWindow->show();
+    }
+        return;
+    case Services::Dailymotion:
+    {
+        DailymotionUserListWindow *dailymotionWindow = new DailymotionUserListWindow(this);
+        dailymotionWindow->search(query);
+        dailymotionWindow->show();
+    }
+        return;
+    default:
+        qWarning() << "HomeWindow::userSearch(): Invalid service";
+        return;
+    }
+}
+
+void HomeWindow::display(const QStringList &urls) {
+    if (!urls.isEmpty()) {
+        this->display(urls.first());
+    }
+}
+
+void HomeWindow::display(const QString &url) {
+    WindowStack::instance()->unwindWindowStack();
     this->activateWindow();
 
     if (url.contains(QRegExp("youtube|youtu.be"))) {
-        m_session->youtube()->getFullVideo(url);
-        this->connect(m_session->youtube(), SIGNAL(gotVideo(QSharedPointer<VideoItem>)), this, SLOT(showYouTubeVideo(QSharedPointer<VideoItem>)));
+        YouTube::instance()->getFullVideo(url);
+        this->connect(YouTube::instance(), SIGNAL(gotVideo(QSharedPointer<VideoItem>)), this, SLOT(showYouTubeVideo(QSharedPointer<VideoItem>)));
     }
     else if (url.contains(QRegExp("dailymotion|dai.ly"))) {
-        m_session->dailymotion()->getFullVideo(url);
-        this->connect(m_session->dailymotion(), SIGNAL(gotVideo(QSharedPointer<VideoItem>)), this, SLOT(showDailymotionVideo(QSharedPointer<VideoItem>)));
+        Dailymotion::instance()->getFullVideo(url);
+        this->connect(Dailymotion::instance(), SIGNAL(gotVideo(QSharedPointer<VideoItem>)), this, SLOT(showDailymotionVideo(QSharedPointer<VideoItem>)));
     }
     else if (url.contains("vimeo")) {
-        m_session->vimeo()->getFullVideo(url);
-        this->connect(m_session->vimeo(), SIGNAL(gotVideo(QSharedPointer<VideoItem>)), this, SLOT(showVimeoVideo(QSharedPointer<VideoItem>)));
+        Vimeo::instance()->getFullVideo(url);
+        this->connect(Vimeo::instance(), SIGNAL(gotVideo(QSharedPointer<VideoItem>)), this, SLOT(showVimeoVideo(QSharedPointer<VideoItem>)));
     }
 }
 
-void HomeWindow::playVideo(const QString &url) {
+void HomeWindow::play(const QStringList &urls) {
+    if (!urls.isEmpty()) {
+        this->play(urls.first());
+    }
+}
+
+void HomeWindow::play(const QString &url) {
     Q_UNUSED(url);
 
     this->activateWindow();
 }
 
 void HomeWindow::showYouTubeVideo(QSharedPointer<VideoItem> video) {
-    YouTubeVideoInfoWindow *window = new YouTubeVideoInfoWindow(m_session, video, this);
+    YouTubeVideoInfoWindow *window = new YouTubeVideoInfoWindow(video, this);
     window->show();
 
-    this->disconnect(m_session->youtube(), SIGNAL(gotVideo(QSharedPointer<VideoItem>)), this, SLOT(showYouTubeVideo(QSharedPointer<VideoItem>)));
+    this->disconnect(YouTube::instance(), SIGNAL(gotVideo(QSharedPointer<VideoItem>)), this, SLOT(showYouTubeVideo(QSharedPointer<VideoItem>)));
 }
 
 void HomeWindow::showDailymotionVideo(QSharedPointer<VideoItem> video) {
-    DailymotionVideoInfoWindow *window = new DailymotionVideoInfoWindow(m_session, video, this);
+    DailymotionVideoInfoWindow *window = new DailymotionVideoInfoWindow(video, this);
     window->show();
 
-    this->disconnect(m_session->dailymotion(), SIGNAL(gotVideo(QSharedPointer<VideoItem>)), this, SLOT(showDailymotionVideo(QSharedPointer<VideoItem>)));
+    this->disconnect(Dailymotion::instance(), SIGNAL(gotVideo(QSharedPointer<VideoItem>)), this, SLOT(showDailymotionVideo(QSharedPointer<VideoItem>)));
 }
 
 void HomeWindow::showVimeoVideo(QSharedPointer<VideoItem> video) {
-    VimeoVideoInfoWindow *window = new VimeoVideoInfoWindow(m_session, video, this);
+    VimeoVideoInfoWindow *window = new VimeoVideoInfoWindow(video, this);
     window->show();
 
-    this->disconnect(m_session->vimeo(), SIGNAL(gotVideo(QSharedPointer<VideoItem>)), this, SLOT(showVimeoVideo(QSharedPointer<VideoItem>)));
+    this->disconnect(Vimeo::instance(), SIGNAL(gotVideo(QSharedPointer<VideoItem>)), this, SLOT(showVimeoVideo(QSharedPointer<VideoItem>)));
 }
 
 void HomeWindow::showPlaybackQueue() {
-    PlaybackQueueWindow *window = new PlaybackQueueWindow(m_session, this);
+    PlaybackQueueWindow *window = new PlaybackQueueWindow(this);
     window->show();
 }
 
 void HomeWindow::showTransfers() {
-    TransferListWindow *window = new TransferListWindow(m_session, this);
+    TransferListWindow *window = new TransferListWindow(this);
     window->show();
 }
 
 void HomeWindow::showArchive() {
-    ArchiveWindow *window = new ArchiveWindow(m_session, this);
+    ArchiveWindow *window = new ArchiveWindow(this);
     window->show();
 }
 
 void HomeWindow::showAccounts() {
-    AccountsDialog *dialog = new AccountsDialog(m_session, this);
+    AccountsDialog *dialog = new AccountsDialog(this);
     dialog->open();
 }
 
@@ -494,16 +615,16 @@ void HomeWindow::showSocialSignInDialog() {
 }
 
 void HomeWindow::showLinkGoogleAccountDialog() {
-    LinkGoogleAccountDialog *dialog = new LinkGoogleAccountDialog(m_session, this);
+    LinkGoogleAccountDialog *dialog = new LinkGoogleAccountDialog(this);
     dialog->show();
 }
 
 void HomeWindow::showFacebookAuthDialog() {
-    FacebookAuthDialog *dialog = new FacebookAuthDialog(m_session, this);
+    FacebookAuthDialog *dialog = new FacebookAuthDialog(this);
     dialog->open();
 }
 
 void HomeWindow::showTwitterAuthDialog() {
-    TwitterAuthDialog *dialog = new TwitterAuthDialog(m_session, this);
+    TwitterAuthDialog *dialog = new TwitterAuthDialog(this);
     dialog->open();
 }
