@@ -3,7 +3,6 @@
 
 #include <QWidget>
 
-class Session;
 class ListView;
 class QModelIndex;
 class QMaemo5EditBar;
@@ -14,7 +13,7 @@ class PlaybackVideoSelectionWindow : public QWidget
 {
     Q_OBJECT
 public:
-    explicit PlaybackVideoSelectionWindow(Session *session, const QString &text, const char* slot, QWidget *parent);
+    explicit PlaybackVideoSelectionWindow(const QString &text, const char* slot, QWidget *parent);
     ~PlaybackVideoSelectionWindow();
     void positionAtIndex(const QModelIndex &index);
 
@@ -29,7 +28,6 @@ signals:
     void accepted();
 
 private:
-    Session *m_session;
     ListView *m_listView;
     QMaemo5EditBar *m_editBar;
     QPushButton *m_acceptButton;
