@@ -1,6 +1,7 @@
 #include "ratingindicator.h"
 #include <QImage>
 #include <QPainter>
+#include <QMaemo5Style>
 
 RatingIndicator::RatingIndicator(int value, int count, QWidget *parent) :
     QWidget(parent),
@@ -38,6 +39,6 @@ void RatingIndicator::paintEvent(QPaintEvent *event) {
 
     painter.setFont(font);
     painter.setOpacity(1);
-    painter.setPen(QColor("#4d4d4d"));
+    painter.setPen(QMaemo5Style::standardColor("SecondaryTextColor"));
     painter.drawText(ratingRect, Qt::AlignVCenter, QString(" (%1)").arg(this->count()));
 }
