@@ -1,13 +1,14 @@
 #include "videoplaybackwindow.h"
-#include "../base/session.h"
+#include "../base/settings.h"
+#include "../base/screensaver.h"
 #include <QVBoxLayout>
 
-VideoPlaybackWindow::VideoPlaybackWindow(Session *session, QList< QSharedPointer<VideoItem> > playlist, QWidget *parent) :
-    StackedWindow(session, parent),
-    m_oldOrientation(m_session->settings()->screenOrientation()),
+VideoPlaybackWindow::VideoPlaybackWindow(QList< QSharedPointer<VideoItem> > playlist, QWidget *parent) :
+    StackedWindow(parent),
+    m_oldOrientation(Settings::instance()->screenOrientation()),
     m_videoWidget(new VideoWidget(this)),
     m_player(new QMediaPlayer(this)),
-    m_controls(new VideoControls(m_session, m_player, playlist, this))
+    m_controls(new VideoControls(m_player, playlist, this))
 {
     this->setWindowState(Qt::WindowFullScreen);
     this->setWindowTitle(tr("Now playing"));
@@ -19,8 +20,8 @@ VideoPlaybackWindow::VideoPlaybackWindow(Session *session, QList< QSharedPointer
     vbox->addWidget(m_videoWidget);
     vbox->addWidget(m_controls);
 
-    m_session->settings()->setScreenOrientation(ScreenOrientation::LockLandscape);
-    m_session->preventDisturb(true);
+    Settings::instance()->setScreenOrientation(ScreenOrientation::LockLandscape);
+    ScreenSaver::preventBlanking(this->winId(), true);
 
     m_player->setVideoOutput(m_videoWidget);
     m_player->setVolume(100);
@@ -29,12 +30,13 @@ VideoPlaybackWindow::VideoPlaybackWindow(Session *session, QList< QSharedPointer
 
     this->connect(m_videoWidget, SIGNAL(clicked()), this, SLOT(toggleControls()));
     this->connect(m_controls, SIGNAL(back()), this, SLOT(close()));
+    this->connect(m_player, SIGNAL(stateChanged(QMediaPlayer::State)), this, SLOT(onStateChanged(QMediaPlayer::State)));
 }
 
 VideoPlaybackWindow::~VideoPlaybackWindow() {
     m_player->stop();
-    m_session->settings()->setScreenOrientation(m_oldOrientation);
-    m_session->preventDisturb(false);
+    Settings::instance()->setScreenOrientation(m_oldOrientation);
+    ScreenSaver::preventBlanking(this->winId(), false);
 }
 
 void VideoPlaybackWindow::toggleControls() {
@@ -44,10 +46,12 @@ void VideoPlaybackWindow::toggleControls() {
 bool VideoPlaybackWindow::event(QEvent *e) {
     switch (e->type()) {
     case QEvent::WindowActivate:
-        m_session->preventDisturb(m_player->state() == QMediaPlayer::PlayingState);
+        ScreenSaver::preventBlanking(this->winId(), m_player->state() == QMediaPlayer::PlayingState);
         break;
     case QEvent::WindowDeactivate:
-        m_session->preventDisturb(false);
+        ScreenSaver::preventBlanking(this->winId(), false);
+        break;
+    default:
         break;
     }
 
@@ -58,12 +62,23 @@ void VideoPlaybackWindow::keyPressEvent(QKeyEvent *event) {
     switch (event->key()) {
     case Qt::Key_F:
         this->toggleControls();
-        break;
+        return;
     case Qt::Key_Backspace:
         this->close();
-        break;
+        return;
     default:
         m_controls->keyPressEvent(event);
-        break;
+        return;
+    }
+}
+
+void VideoPlaybackWindow::onStateChanged(QMediaPlayer::State state) {
+    switch (state) {
+    case QMediaPlayer::PlayingState:
+        ScreenSaver::preventBlanking(this->winId(), this->isActiveWindow());
+        return;
+    default:
+        ScreenSaver::preventBlanking(this->winId(), false);
+        return;
     }
 }
