@@ -12,6 +12,7 @@
 #include <QAction>
 #include <QGridLayout>
 #include <QDesktopServices>
+#include <QMaemo5Style>
 
 VimeoProfileTab::VimeoProfileTab(const QString &userId, QWidget *parent) :
     AbstractTab(parent),
@@ -22,7 +23,7 @@ VimeoProfileTab::VimeoProfileTab(const QString &userId, QWidget *parent) :
     m_locationLabel(new QLabel(this)),
     m_websiteLabel(new QLabel(this)),
     m_descriptionLabel(new QLabel(this)),
-    m_noProfileLabel(new QLabel(QString("<p style='color:#4d4d4d;font-size:40px;'><center><b>%1</b></center></p>").arg(tr("No profile found")), this)),
+    m_noProfileLabel(new QLabel(QString("<p style='color:%1;font-size:40px;'><center><b>%2</b></center></p>").arg(QMaemo5Style::standardColor("SecondaryTextColor").name()).arg(tr("No profile found")), this)),
     m_subscriptionButton(new QPushButton(tr("Subscribe"))),
     m_watchLaterAction(new QAction(tr("Show 'Watch later' album"), this)),
     m_scrollArea(new QScrollArea(this)),
