@@ -4,7 +4,6 @@
 #include "abstracttab.h"
 #include "../base/useritem.h"
 
-class Session;
 class SeparatorLabel;
 class AvatarLabel;
 class QLabel;
@@ -18,7 +17,7 @@ class VimeoProfileTab : public AbstractTab
     Q_OBJECT
 
 public:
-    explicit VimeoProfileTab(Session *session, const QString &userId, QWidget *parent = 0);
+    explicit VimeoProfileTab(const QString &userId, QWidget *parent = 0);
 
 private:
     void setLandscapeLayout();
@@ -34,7 +33,6 @@ private slots:
     void showWatchLaterAlbum();
 
 private:
-    Session *m_session;
     QSharedPointer<UserItem> m_user;
     AvatarLabel *m_avatar;
     QLabel *m_channelLabel;
