@@ -17,6 +17,7 @@
 #include <QLabel>
 #include <QGridLayout>
 #include <QMenu>
+#include <QMaemo5Style>
 
 VimeoRelatedVideosTab::VimeoRelatedVideosTab(QSharedPointer<VideoItem> video, QWidget *parent) :
     AbstractTab(parent),
@@ -36,7 +37,7 @@ VimeoRelatedVideosTab::VimeoRelatedVideosTab(QSharedPointer<VideoItem> video, QW
     m_addToQueueContextAction(m_contextMenu->addAction(tr("Add to playback queue"), this, SLOT(queueVideo()))),
     m_videoDownloadContextAction(m_contextMenu->addAction(tr("Download"), this, SLOT(addVideoDownload()))),
     m_audioDownloadContextAction(m_contextMenu->addAction(tr("Download (audio)"), this, SLOT(addAudioDownload()))),
-    m_noResultsLabel(new QLabel(QString("<p style='color:#4d4d4d;font-size:40px;'><center><b>%1</b></center></p>").arg(tr("No videos found")), this)),
+    m_noResultsLabel(new QLabel(QString("<p style='color:%1;font-size:40px;'><center><b>%2</b></center></p>").arg(QMaemo5Style::standardColor("SecondaryTextColor").name()).arg(tr("No videos found")), this)),
     m_grid(new QGridLayout(this))
 {
     this->addAction(m_addToLikesAction);
