@@ -10,6 +10,7 @@
 #include <QMenu>
 #include <QAction>
 #include <QGridLayout>
+#include <QMaemo5Style>
 
 VimeoUserGroupListTab::VimeoUserGroupListTab(QWidget *parent) :
     AbstractTab(parent),
@@ -17,7 +18,7 @@ VimeoUserGroupListTab::VimeoUserGroupListTab(QWidget *parent) :
     m_model(new VimeoUserGroupListModel(this)),
     m_contextMenu(new QMenu(this)),
     m_leaveAction(m_contextMenu->addAction(tr("Leave group"), this, SLOT(leaveGroup()))),
-    m_noResultsLabel(new QLabel(QString("<p style='color:#4d4d4d;font-size:40px;'><center><b>%1</b></center></p>").arg(tr("No groups found")), this)),
+    m_noResultsLabel(new QLabel(QString("<p style='color:%1;font-size:40px;'><center><b>%2</b></center></p>").arg(QMaemo5Style::standardColor("SecondaryTextColor").name()).arg(tr("No groups found")), this)),
     m_grid(new QGridLayout(this))
 {
     m_grid->setContentsMargins(0, 0, 0, 0);
