@@ -2,6 +2,7 @@
 #include "../base/abstractuserlistmodel.h"
 #include <QApplication>
 #include <QPainter>
+#include <QMaemo5Style>
 
 VimeoUserListDelegate::VimeoUserListDelegate(QObject *parent) :
     QStyledItemDelegate(parent)
@@ -28,7 +29,7 @@ void VimeoUserListDelegate::paint(QPainter *painter, const QStyleOptionViewItem
         painter->drawImage(imageRect, image);
     }
 
-    painter->setPen(QColor("#4d4d4d"));
+    painter->setPen(QMaemo5Style::standardColor("SecondaryTextColor"));
     painter->drawRect(imageRect);
     painter->setPen(Qt::white);
 
