@@ -8,13 +8,14 @@
 #include "listview.h"
 #include <QLabel>
 #include <QGridLayout>
+#include <QMaemo5Style>
 
 VimeoUserListTab::VimeoUserListTab(const QString &userId, QWidget *parent) :
     AbstractTab(parent),
     m_userId(userId),
     m_model(new VimeoUserListModel(this)),
     m_listView(new ListView(this)),
-    m_noResultsLabel(new QLabel(QString("<p style='color:#4d4d4d;font-size:40px;'><center><b>%1</b></center></p>").arg(tr("No subscriptions found")), this)),
+    m_noResultsLabel(new QLabel(QString("<p style='color:%1;font-size:40px;'><center><b>%2</b></center></p>").arg(QMaemo5Style::standardColor("SecondaryTextColor").name()).arg(tr("No subscriptions found")), this)),
     m_grid(new QGridLayout(this))
 {
     m_grid->setContentsMargins(0, 0, 0, 0);
