@@ -14,8 +14,8 @@ class YouTubePlaylistListWindow : public StackedWindow
 {
     Q_OBJECT
 public:
-    explicit YouTubePlaylistListWindow(Session *session, QWidget *parent);
-    void setPlaylistFeed(const QString &feed);
+    explicit YouTubePlaylistListWindow(QWidget *parent);
+    void setPlaylistFeed(const QUrl &feed);
     void search(const QString &query, Queries::QueryOrder order);
 
 private:
