@@ -6,7 +6,6 @@
 #include <QVariantMap>
 
 class YouTubeVideoListModel;
-class Session;
 class ListView;
 class QMaemo5EditBar;
 class QPushButton;
@@ -16,8 +15,9 @@ class QModelIndex;
 class YouTubeVideoSelectionWindow : public QWidget
 {
     Q_OBJECT
+
 public:
-    explicit YouTubeVideoSelectionWindow(Session *session, YouTubeVideoListModel *model, const QString &text, const char* slot, QWidget *parent);
+    explicit YouTubeVideoSelectionWindow(YouTubeVideoListModel *model, const QString &text, const char* slot, QWidget *parent);
     ~YouTubeVideoSelectionWindow();
     void positionAtIndex(const QModelIndex &index);
 
@@ -41,7 +41,6 @@ signals:
     void accepted();
 
 private:
-    Session *m_session;
     YouTubeVideoListModel *m_model;
     ListView *m_listView;
     QMaemo5EditBar *m_editBar;
