@@ -67,7 +67,7 @@ void Dailymotion::refreshAccessToken() {
 }
 
 void Dailymotion::checkTokenRefresh() {
-    QNetworkReply* reply = qobject_cast<QNetworkReply*>(sender());
+    QNetworkReply* reply = qobject_cast<QNetworkReply*>(this->sender());
 
     if (!reply) {
         emit refreshError();
