@@ -1,31 +1,14 @@
 #include "database.h"
-#include <QDir>
 #include <QSqlQuery>
 #include <QSqlRecord>
 #include <QSqlError>
-#include <QDebug>
 #include <QVariant>
 
 Database::Database(QObject *parent) :
     QObject(parent)
 {
-    QDir dir;
-    dir.mkpath("/home/user/cuteTube/");
     m_database = QSqlDatabase::addDatabase("QSQLITE");
-    m_database.setDatabaseName("/home/user/cuteTube/cuteTube.sqlite");
-    initialize();
-}
-
-void Database::initialize() {
-    if (m_database.open()) {
-        m_database.exec("CREATE TABLE IF NOT EXISTS youtubeAccounts (name TEXT UNIQUE, username TEXT, token TEXT, refresh TEXT, cookies TEXT, active INTEGER)");
-        m_database.exec("CREATE TABLE IF NOT EXISTS dailymotionAccounts (name TEXT UNIQUE, username TEXT, token TEXT, refresh TEXT, cookies TEXT, active INTEGER)");
-        m_database.exec("CREATE TABLE IF NOT EXISTS vimeoAccounts (name TEXT UNIQUE, username TEXT, token TEXT, secret TEXT, cookies TEXT, active INTEGER)");
-        m_database.close();
-    }
-    else {
-        qDebug() << m_database.lastError().text();
-    }
+    m_database.setDatabaseName("/home/user/cuteTube/cuteTube.db");
 }
 
 void Database::restoreAccounts() {
