@@ -384,15 +384,7 @@ void Events::addEvents() {
         itemArgs.insert("action", event.action());
         args.append(itemArgs);
 
-        QDBusMessage message = QDBusMessage::createMethodCall(
-                    "com.nokia.home.EventFeed",
-                    "/eventfeed",
-                    "com.nokia.home.EventFeed",
-                    "addItem");
-        message.setArguments(args);
-
-        QDBusConnection bus = QDBusConnection::sessionBus();
-        bus.callWithCallback(message, this, SLOT(dbusRequestCompleted(QDBusMessage)), SLOT(dbusError(QDBusError,QDBusMessage)));
+        QDBusInterface("com.nokia.home.EventFeed", "/eventfeed", "com.nokia.home.EventFeed").callWithArgumentList(QDBus::Block, "addItem", args);
     }
 #else
     while (!m_events.isEmpty()) {
@@ -415,19 +407,6 @@ void Events::addEvents() {
 }
 
 #ifdef MEEGO_EDITION_HARMATTAN
-void Events::dbusRequestCompleted(const QDBusMessage &message) {
-    if (message.arguments().first().toInt() < 0) {
-        this->syncFailed();
-    }
-}
-
-void Events::dbusError(const QDBusError &error, const QDBusMessage &message) {
-    Q_UNUSED(error)
-    Q_UNUSED(message)
-
-    this->syncFailed();
-}
-
 QString Events::base64SerializedVariant(const QVariant &value) const
 {
     QByteArray ba;
