@@ -39,8 +39,6 @@ private slots:
     void processVimeoEvents();
 #ifdef MEEGO_EDITION_HARMATTAN
     void onThumbnailDownloaded();
-    void dbusRequestCompleted(const QDBusMessage &message);
-    void dbusError(const QDBusError &error, const QDBusMessage &message);
 #endif
 
 private:
