@@ -55,7 +55,7 @@ void YouTube::refreshAccessToken() {
 }
 
 void YouTube::checkTokenRefresh() {
-    QNetworkReply* reply = qobject_cast<QNetworkReply*>(sender());
+    QNetworkReply* reply = qobject_cast<QNetworkReply*>(this->sender());
 
     if (!reply) {
         emit refreshError();
